@@ -1,12 +1,15 @@
 import datetime
 import pathlib
 import time
+import uuid
 from typing import Generator, List, Optional, Union
 
 import pytest
+from _pytest.fixtures import SubRequest
 
 import weaviate
 import weaviate.classes as wvc
+from weaviate.auth import Auth
 from weaviate.backup.backup import (
     BackupCompressionLevel,
     BackupConfigCreate,
@@ -20,9 +23,7 @@ from weaviate.exceptions import (
     UnexpectedStatusCodeException,
 )
 
-from weaviate.auth import Auth
 from .conftest import ClientFactory, _sanitize_collection_name
-from _pytest.fixtures import SubRequest
 
 RBAC_PORTS = (8093, 50065)
 RBAC_AUTH_CREDS = Auth.api_key("admin-key")
@@ -121,18 +122,26 @@ def client() -> Generator[weaviate.WeaviateClient, None, None]:
     client.collections.delete("Article")
 
 
-def _create_backup_id() -> str:
-    return str(round(time.time_ns() * 1000))
+def unique_backup_id(name: str) -> str:
+    """Generate a unique backup ID based on the test name."""
+    name = _sanitize_collection_name(name)
+    random_part = str(uuid.uuid4()).replace("-", "")[:12]
+    return name + random_part
 
 
-def test_create_and_restore_backup_with_waiting(client: weaviate.WeaviateClient) -> None:
+def test_create_and_restore_backup_with_waiting(
+    client: weaviate.WeaviateClient, request: SubRequest
+) -> None:
     """Create and restore backup with waiting."""
-    backup_id = _create_backup_id()
+    backup_id = unique_backup_id(request.node.name)
 
     # create backup
     classes = ["Article", "Paragraph"]
     resp = client.backup.create(
-        backup_id=backup_id, backend=BACKEND, wait_for_completion=True, include_collections=CLASSES
+        backup_id=backup_id,
+        backend=BACKEND,
+        wait_for_completion=True,
+        include_collections=CLASSES,
     )
     assert resp.status == BackupStatus.SUCCESS
     for cls in classes:
@@ -144,7 +153,7 @@ def test_create_and_restore_backup_with_waiting(client: weaviate.WeaviateClient)
     # check create status
     create_status = client.backup.get_create_status(backup_id, BACKEND)
     assert create_status.status == BackupStatus.SUCCESS
-    assert create_status.backup_id == backup_id
+    assert create_status.backup_id.lower() == backup_id.lower()
 
     # remove existing class
     client.collections.delete("Article")
@@ -152,7 +161,10 @@ def test_create_and_restore_backup_with_waiting(client: weaviate.WeaviateClient)
 
     # restore backup
     restore = client.backup.restore(
-        backup_id=backup_id, backend=BACKEND, wait_for_completion=True, include_collections=CLASSES
+        backup_id=backup_id,
+        backend=BACKEND,
+        wait_for_completion=True,
+        include_collections=CLASSES,
     )
     assert restore.status == BackupStatus.SUCCESS
     for cls in classes:
@@ -169,10 +181,10 @@ def test_create_and_restore_backup_with_waiting(client: weaviate.WeaviateClient)
 
 @pytest.mark.parametrize("include", [["Article"], "Article"])
 def test_create_and_restore_backup_without_waiting(
-    client: weaviate.WeaviateClient, include: Union[str, List[str]]
+    client: weaviate.WeaviateClient, include: Union[str, List[str]], request: SubRequest
 ) -> None:
     """Create and restore backup without waiting."""
-    backup_id = _create_backup_id()
+    backup_id = unique_backup_id(request.node.name)
     include_as_list = sorted(include) if isinstance(include, list) else [include]
 
     resp = client.backup.create(backup_id=backup_id, include_collections=include, backend=BACKEND)
@@ -222,9 +234,11 @@ def test_create_and_restore_backup_without_waiting(
     assert len(client.collections.use("Article")) == len(ARTICLES_IDS)
 
 
-def test_create_and_restore_1_of_2_classes(client: weaviate.WeaviateClient) -> None:
+def test_create_and_restore_1_of_2_classes(
+    client: weaviate.WeaviateClient, request: SubRequest
+) -> None:
     """Create and restore 1 of 2 classes."""
-    backup_id = _create_backup_id()
+    backup_id = unique_backup_id(request.node.name)
 
     # check data exists
     assert len(client.collections.use("Article")) == len(ARTICLES_IDS)
@@ -232,7 +246,10 @@ def test_create_and_restore_1_of_2_classes(client: weaviate.WeaviateClient) -> N
     # create backup
     include = ["Article"]
     create = client.backup.create(
-        backup_id=backup_id, include_collections=include, backend=BACKEND, wait_for_completion=True
+        backup_id=backup_id,
+        include_collections=include,
+        backend=BACKEND,
+        wait_for_completion=True,
     )
     assert create.status == BackupStatus.SUCCESS
 
@@ -245,7 +262,10 @@ def test_create_and_restore_1_of_2_classes(client: weaviate.WeaviateClient) -> N
 
     # restore backup
     restore = client.backup.restore(
-        backup_id=backup_id, include_collections=include, backend=BACKEND, wait_for_completion=True
+        backup_id=backup_id,
+        include_collections=include,
+        backend=BACKEND,
+        wait_for_completion=True,
     )
     assert restore.status == BackupStatus.SUCCESS
 
@@ -257,9 +277,9 @@ def test_create_and_restore_1_of_2_classes(client: weaviate.WeaviateClient) -> N
     assert restore_status.status == BackupStatus.SUCCESS
 
 
-def test_fail_on_non_existing_class(client: weaviate.WeaviateClient) -> None:
+def test_fail_on_non_existing_class(client: weaviate.WeaviateClient, request: SubRequest) -> None:
     """Fail backup functions on non-existing class."""
-    backup_id = _create_backup_id()
+    backup_id = unique_backup_id(request.node.name)
     class_name = "NonExistingClass"
     for func in [client.backup.create, client.backup.restore]:
         with pytest.raises(UnexpectedStatusCodeException) as excinfo:
@@ -268,9 +288,11 @@ def test_fail_on_non_existing_class(client: weaviate.WeaviateClient) -> None:
             assert "422" in str(excinfo.value)
 
 
-def test_fail_restoring_backup_for_existing_class(client: weaviate.WeaviateClient) -> None:
+def test_fail_restoring_backup_for_existing_class(
+    client: weaviate.WeaviateClient, request: SubRequest
+) -> None:
     """Fail restoring backup for existing class."""
-    backup_id = _create_backup_id()
+    backup_id = unique_backup_id(request.node.name)
     class_name = ["Article"]
     create = client.backup.create(
         backup_id=backup_id,
@@ -292,9 +314,11 @@ def test_fail_restoring_backup_for_existing_class(client: weaviate.WeaviateClien
         assert "already exists" in str(excinfo.value)
 
 
-def test_fail_creating_existing_backup(client: weaviate.WeaviateClient) -> None:
+def test_fail_creating_existing_backup(
+    client: weaviate.WeaviateClient, request: SubRequest
+) -> None:
     """Fail creating existing backup."""
-    backup_id = _create_backup_id()
+    backup_id = unique_backup_id(request.node.name)
     class_name = ["Article"]
     create = client.backup.create(
         backup_id=backup_id,
@@ -316,18 +340,22 @@ def test_fail_creating_existing_backup(client: weaviate.WeaviateClient) -> None:
         assert "422" in str(excinfo.value)
 
 
-def test_fail_restoring_non_existing_backup(client: weaviate.WeaviateClient) -> None:
+def test_fail_restoring_non_existing_backup(
+    client: weaviate.WeaviateClient, request: SubRequest
+) -> None:
     """Fail restoring non-existing backup."""
-    backup_id = _create_backup_id()
+    backup_id = unique_backup_id(request.node.name)
     with pytest.raises(UnexpectedStatusCodeException) as excinfo:
         client.backup.restore(backup_id=backup_id, backend=BACKEND, wait_for_completion=True)
         assert backup_id in str(excinfo.value)
         assert "404" in str(excinfo.value)
 
 
-def test_fail_checking_status_for_non_existing_restore(client: weaviate.WeaviateClient) -> None:
+def test_fail_checking_status_for_non_existing_restore(
+    client: weaviate.WeaviateClient, request: SubRequest
+) -> None:
     """Fail checking restore status for non-existing restore."""
-    backup_id = _create_backup_id()
+    backup_id = unique_backup_id(request.node.name)
     for func in [client.backup.get_restore_status, client.backup.get_create_status]:
         with pytest.raises(UnexpectedStatusCodeException) as excinfo:
             func(
@@ -339,10 +367,10 @@ def test_fail_checking_status_for_non_existing_restore(client: weaviate.Weaviate
 
 
 def test_fail_creating_backup_for_both_include_and_exclude_classes(
-    client: weaviate.WeaviateClient,
+    client: weaviate.WeaviateClient, request: SubRequest
 ) -> None:
     """Fail creating backup for both include and exclude classes."""
-    backup_id = _create_backup_id()
+    backup_id = unique_backup_id(request.node.name)
 
     for func in [client.backup.create, client.backup.restore]:
         with pytest.raises(TypeError) as excinfo:
@@ -362,9 +390,12 @@ def test_fail_creating_backup_for_both_include_and_exclude_classes(
 
 @pytest.mark.parametrize("dynamic_backup_location", [False, True])
 def test_backup_and_restore_with_dynamic_location(
-    client: weaviate.WeaviateClient, dynamic_backup_location: bool, tmp_path: pathlib.Path
+    client: weaviate.WeaviateClient,
+    dynamic_backup_location: bool,
+    tmp_path: pathlib.Path,
+    request: SubRequest,
 ) -> None:
-    backup_id = _create_backup_id()
+    backup_id = unique_backup_id(request.node.name)
 
     conf_create: Optional[wvc.backup.BackupConfigCreate] = None
     conf_restore: Optional[wvc.backup.BackupConfigRestore] = None
@@ -417,12 +448,12 @@ def test_backup_and_restore_with_dynamic_location(
 
 
 def test_backup_and_restore_with_collection_and_config_1_24_x(
-    client: weaviate.WeaviateClient,
+    client: weaviate.WeaviateClient, request: SubRequest
 ) -> None:
     if client._connection._weaviate_version.is_lower_than(1, 25, 0):
         pytest.skip("Backup config is only supported from Weaviate 1.25.0")
 
-    backup_id = _create_backup_id()
+    backup_id = unique_backup_id(request.node.name)
 
     article = client.collections.use("Article")
 
@@ -432,7 +463,8 @@ def test_backup_and_restore_with_collection_and_config_1_24_x(
         backend=BACKEND,
         wait_for_completion=True,
         config=BackupConfigCreate(
-            cpu_percentage=60, chunk_size=256, compression_level=BackupCompressionLevel.BEST_SPEED
+            cpu_percentage=60,
+            compression_level=BackupCompressionLevel.BEST_SPEED,
         ),
     )
     assert create.status == BackupStatus.SUCCESS
@@ -463,26 +495,15 @@ def test_backup_and_restore_with_collection_and_config_1_24_x(
     assert restore_status.status == BackupStatus.SUCCESS
 
 
-# did not make it into 1.27, will come later
-# def test_list_backup(client: weaviate.WeaviateClient) -> None:
-#     """Create and restore backup without waiting."""
-#     backup_id = _create_backup_id()
-#     if client._connection._weaviate_version.is_lower_than(1, 27, 0):
-#         pytest.skip("List backups is only supported from 1.27.0")
-#
-#     resp = client.backup.create(backup_id=backup_id, backend=BACKEND)
-#     assert resp.status == BackupStatus.STARTED
-#
-#     backups = client.backup.list_backups(backend=BACKEND)
-#     assert backup_id in [b.backup_id for b in backups]
-
-
 @pytest.mark.parametrize("dynamic_backup_location", [False, True])
 def test_cancel_backup(
-    client: weaviate.WeaviateClient, dynamic_backup_location, tmp_path: pathlib.Path
+    client: weaviate.WeaviateClient,
+    dynamic_backup_location: bool,
+    tmp_path: pathlib.Path,
+    request: SubRequest,
 ) -> None:
-    """Create and restore backup without waiting."""
-    backup_id = _create_backup_id()
+    """Cancel backup without waiting."""
+    backup_id = unique_backup_id(request.node.name)
     if client._connection._weaviate_version.is_lower_than(1, 24, 25):
         pytest.skip("Cancel backups is only supported from 1.24.25")
 
@@ -524,7 +545,7 @@ def test_cancel_backup(
 def test_backup_and_restore_with_roles_and_users(
     client_factory: ClientFactory, request: SubRequest
 ) -> None:
-    backup_id = _create_backup_id()
+    backup_id = unique_backup_id(request.node.name)
     client = client_factory(ports=RBAC_PORTS, auth_credentials=RBAC_AUTH_CREDS)
     if client._connection._weaviate_version.is_lower_than(1, 30, 10):
         pytest.skip("User and roles are only supported from Weaviate 1.30.10")
@@ -566,3 +587,123 @@ def test_backup_and_restore_with_roles_and_users(
 
     assert client.users.db.get(user_id=name) is not None
     assert client.roles.get(role_name=name) is not None
+
+
+def test_list_backup(client: weaviate.WeaviateClient, request: SubRequest) -> None:
+    """List all backups."""
+    backup_id = unique_backup_id(request.node.name)
+    if client._connection._weaviate_version.is_lower_than(1, 30, 0):
+        pytest.skip("List backups is only supported from 1.30.0")
+
+    resp = client.backup.create(backup_id=backup_id, backend=BACKEND)
+    assert resp.status == BackupStatus.STARTED
+
+    backups = client.backup.list_backups(backend=BACKEND)
+    assert backup_id.lower() in [b.backup_id.lower() for b in backups]
+
+    # wait until created
+    while True:
+        create_status = client.backup.get_create_status(backup_id, BACKEND)
+        assert create_status.status in [
+            BackupStatus.SUCCESS,
+            BackupStatus.TRANSFERRED,
+            BackupStatus.TRANSFERRING,
+            BackupStatus.STARTED,
+        ]
+        if create_status.status == BackupStatus.SUCCESS:
+            break
+        time.sleep(0.1)
+
+
+def test_list_backup_ascending_order(client: weaviate.WeaviateClient, request: SubRequest) -> None:
+    """List all backups in ascending order."""
+    backup_id = unique_backup_id(request.node.name)
+    if client._connection._weaviate_version.is_lower_than(1, 33, 2):
+        pytest.skip("List backups sorting is only supported from 1.33.2")
+
+    resp = client.backup.create(backup_id=backup_id, backend=BACKEND)
+    assert resp.status == BackupStatus.STARTED
+
+    while True:
+        create_status = client.backup.get_create_status(backup_id, BACKEND)
+        assert create_status.status in [
+            BackupStatus.SUCCESS,
+            BackupStatus.TRANSFERRED,
+            BackupStatus.TRANSFERRING,
+            BackupStatus.STARTED,
+        ]
+        if create_status.status == BackupStatus.SUCCESS:
+            break
+        time.sleep(0.1)
+
+    backups = client.backup.list_backups(backend=BACKEND, sort_by_starting_time_asc=True)
+    assert backup_id.lower() in [b.backup_id.lower() for b in backups]
+
+    assert sorted(backups, key=lambda b: b.started_at or b.backup_id) == backups
+
+
+@pytest.fixture
+def artist_alias(client: weaviate.WeaviateClient) -> Generator[str, None, None]:
+    if client._connection._weaviate_version.is_lower_than(1, 32, 0):
+        pytest.skip("overwriteAlias is only supported from 1.33.0 onwards")
+
+    client.alias.create(target_collection="Article", alias_name="Literature")
+    yield "Literature"
+    client.alias.delete(alias_name="Literature")
+
+
+def test_overwrite_alias_true(
+    client: weaviate.WeaviateClient, request: SubRequest, artist_alias: str
+) -> None:
+    """Restore backups with overwrite=true."""
+    backup_id = unique_backup_id(request.node.name)
+    client.backup.create(
+        backup_id=backup_id,
+        backend=BACKEND,
+        include_collections=["Article"],
+        wait_for_completion=True,
+    )
+
+    client.collections.delete("Article")
+    client.alias.update(alias_name=artist_alias, new_target_collection="Paragraph")
+
+    client.backup.restore(
+        backup_id=backup_id,
+        backend=BACKEND,
+        include_collections=["Article"],
+        wait_for_completion=True,
+        overwrite_alias=True,
+    )
+
+    literature = client.alias.get(alias_name="Literature")
+    assert literature is not None, "expect alias exists"
+    assert literature.collection == "Article", "alias must point to the original collection"
+
+
+# This test has been disabled temporarily until the behaviour of this scenario is clarified.
+# It worked in version 1.33.0-rc.1, but broken in version 1.33.0+
+# def test_overwrite_alias_false(
+#     client: weaviate.WeaviateClient, request: SubRequest, artist_alias: str
+# ) -> None:
+#     """Restore backups with overwrite=false (conflict)."""
+#     backup_id = unique_backup_id(request.node.name)
+
+#     client.backup.create(
+#         backup_id=backup_id,
+#         backend=BACKEND,
+#         include_collections=["Article"],
+#         wait_for_completion=True,
+#     )
+
+#     client.collections.delete("Article")
+#     client.alias.update(alias_name=artist_alias, new_target_collection="Paragraph")
+
+#     with pytest.raises(BackupFailedError) as err:
+#         client.backup.restore(
+#             backup_id=backup_id,
+#             backend=BACKEND,
+#             include_collections=["Article"],
+#             wait_for_completion=True,
+#             overwrite_alias=False,
+#         )
+#     assert "alias already exists" in str(err)
