@@ -7,11 +7,8 @@ from typing import Any, Callable, Dict, List, Optional, Sequence, TypedDict, Uni
 
 import pytest
 
-from integration.conftest import (
-    CollectionFactory,
-    CollectionFactoryGet,
-    _sanitize_collection_name,
-)
+import weaviate.classes as wvc
+from integration.conftest import CollectionFactory, CollectionFactoryGet, _sanitize_collection_name
 from integration.constants import WEAVIATE_LOGO_NEW_ENCODED, WEAVIATE_LOGO_OLD_ENCODED
 from weaviate.collections.classes.batch import ErrorObject
 from weaviate.collections.classes.config import (
@@ -23,9 +20,7 @@ from weaviate.collections.classes.config import (
     Tokenization,
     Vectorizers,
 )
-from weaviate.collections.classes.data import (
-    DataObject,
-)
+from weaviate.collections.classes.data import DataObject
 from weaviate.collections.classes.grpc import (
     PROPERTIES,
     PROPERTY,
@@ -39,28 +34,17 @@ from weaviate.collections.classes.grpc import (
     Sort,
     _Sorting,
 )
-from weaviate.collections.classes.internal import (
-    Object,
-    ReferenceToMulti,
-    _CrossReference,
-)
-from weaviate.collections.classes.types import (
-    PhoneNumber,
-    WeaviateProperties,
-    _PhoneNumber,
-)
+from weaviate.collections.classes.internal import Object, ReferenceToMulti, _CrossReference
+from weaviate.collections.classes.types import PhoneNumber, WeaviateProperties, _PhoneNumber
 from weaviate.exceptions import (
     UnexpectedStatusCodeError,
     WeaviateInsertInvalidPropertyError,
     WeaviateInsertManyAllFailedError,
     WeaviateInvalidInputError,
     WeaviateQueryError,
-    WeaviateUnsupportedFeatureError,
 )
 from weaviate.types import UUID, UUIDS
 
-import weaviate.classes as wvc
-
 UUID1 = uuid.UUID("806827e0-2b31-43ca-9269-24fa95a221f9")
 UUID2 = uuid.UUID("8ad0d33c-8db1-4437-87f3-72161ca2a51a")
 UUID3 = uuid.UUID("83d99755-9deb-4b16-8431-d1dff4ab0a75")
@@ -584,17 +568,11 @@ def test_bm25_group_by(collection_factory: CollectionFactory) -> None:
         ]
     )
     assert res.has_errors is False
-    if collection._connection.supports_groupby_in_bm25_and_hybrid():
-        objs = collection.query.bm25(
-            query="test", group_by=GroupBy(prop="name", objects_per_group=1, number_of_groups=2)
-        ).objects
-        assert len(objs) == 1
-        assert objs[0].belongs_to_group == "test"
-    else:
-        with pytest.raises(WeaviateUnsupportedFeatureError):
-            collection.query.bm25(
-                query="test", group_by=GroupBy(prop="name", objects_per_group=1, number_of_groups=2)
-            )
+    objs = collection.query.bm25(
+        query="test", group_by=GroupBy(prop="name", objects_per_group=1, number_of_groups=2)
+    ).objects
+    assert len(objs) == 1
+    assert objs[0].belongs_to_group == "test"
 
 
 @pytest.mark.parametrize("limit", [1, 2])
