@@ -6,12 +6,14 @@ from _pytest.fixtures import SubRequest
 from integration.conftest import ClientFactory, _sanitize_collection_name
 from weaviate.auth import Auth
 from weaviate.classes.rbac import Actions, Permissions, RoleScope
+from weaviate.connect.helpers import connect_to_local
 from weaviate.rbac.models import (
     AliasPermissionOutput,
     BackupsPermissionOutput,
     ClusterPermissionOutput,
     CollectionsPermissionOutput,
     DataPermissionOutput,
+    GroupsPermissionOutput,
     NodesPermissionOutput,
     Role,
     ReplicatePermissionOutput,
@@ -45,6 +47,7 @@ RBAC_AUTH_CREDS = Auth.api_key("admin-key")
                 nodes_permissions=[],
                 tenants_permissions=[],
                 replicate_permissions=[],
+                groups_permissions=[],
             ),
             None,
         ),
@@ -62,6 +65,7 @@ RBAC_AUTH_CREDS = Auth.api_key("admin-key")
                 nodes_permissions=[],
                 tenants_permissions=[],
                 replicate_permissions=[],
+                groups_permissions=[],
             ),
             None,
         ),
@@ -83,6 +87,7 @@ RBAC_AUTH_CREDS = Auth.api_key("admin-key")
                 nodes_permissions=[],
                 tenants_permissions=[],
                 replicate_permissions=[],
+                groups_permissions=[],
             ),
             None,
         ),
@@ -102,6 +107,7 @@ RBAC_AUTH_CREDS = Auth.api_key("admin-key")
                 nodes_permissions=[],
                 tenants_permissions=[],
                 replicate_permissions=[],
+                groups_permissions=[],
             ),
             None,
         ),
@@ -134,6 +140,7 @@ RBAC_AUTH_CREDS = Auth.api_key("admin-key")
                 nodes_permissions=[],
                 tenants_permissions=[],
                 replicate_permissions=[],
+                groups_permissions=[],
             ),
             None,
         ),
@@ -155,6 +162,7 @@ RBAC_AUTH_CREDS = Auth.api_key("admin-key")
                 ],
                 tenants_permissions=[],
                 replicate_permissions=[],
+                groups_permissions=[],
             ),
             None,
         ),
@@ -176,6 +184,7 @@ RBAC_AUTH_CREDS = Auth.api_key("admin-key")
                 ],
                 tenants_permissions=[],
                 replicate_permissions=[],
+                groups_permissions=[],
             ),
             None,
         ),
@@ -197,6 +206,7 @@ RBAC_AUTH_CREDS = Auth.api_key("admin-key")
                 nodes_permissions=[],
                 tenants_permissions=[],
                 replicate_permissions=[],
+                groups_permissions=[],
             ),
             None,
         ),
@@ -220,6 +230,7 @@ RBAC_AUTH_CREDS = Auth.api_key("admin-key")
                     )
                 ],
                 replicate_permissions=[],
+                groups_permissions=[],
             ),
             None,
         ),
@@ -260,6 +271,7 @@ RBAC_AUTH_CREDS = Auth.api_key("admin-key")
                     ),
                 ],
                 replicate_permissions=[],
+                groups_permissions=[],
             ),
             None,
         ),
@@ -281,6 +293,7 @@ RBAC_AUTH_CREDS = Auth.api_key("admin-key")
                 nodes_permissions=[],
                 tenants_permissions=[],
                 replicate_permissions=[],
+                groups_permissions=[],
             ),
             None,
         ),
@@ -321,9 +334,34 @@ RBAC_AUTH_CREDS = Auth.api_key("admin-key")
                         actions={Actions.Replicate.READ, Actions.Replicate.UPDATE},
                     ),
                 ],
+                groups_permissions=[],
             ),
             32,
         ),
+        (
+            Permissions.alias(alias="", collection="*", read=True, delete=True),
+            Role(
+                name="AlliasRole2",
+                alias_permissions=[
+                    AliasPermissionOutput(
+                        alias="*",
+                        collection="*",
+                        actions={Actions.Alias.READ, Actions.Alias.DELETE},
+                    )
+                ],
+                cluster_permissions=[],
+                users_permissions=[],
+                collections_permissions=[],
+                roles_permissions=[],
+                data_permissions=[],
+                backups_permissions=[],
+                nodes_permissions=[],
+                tenants_permissions=[],
+                replicate_permissions=[],
+                groups_permissions=[],
+            ),
+            32,  # Minimum version for alias permissions
+        ),
         (
             Permissions.alias(alias="*", collection="*", read=True, delete=True),
             Role(
@@ -344,6 +382,7 @@ RBAC_AUTH_CREDS = Auth.api_key("admin-key")
                 nodes_permissions=[],
                 tenants_permissions=[],
                 replicate_permissions=[],
+                groups_permissions=[],
             ),
             32,  # Minimum version for alias permissions
         ),
@@ -367,9 +406,34 @@ RBAC_AUTH_CREDS = Auth.api_key("admin-key")
                 nodes_permissions=[],
                 tenants_permissions=[],
                 replicate_permissions=[],
+                groups_permissions=[],
             ),
             32,  # Minimum version for alias permissions
         ),
+        (
+            Permissions.Groups.oidc(group="MyGroup", read=True),
+            Role(
+                name="GroupRole",
+                alias_permissions=[],
+                cluster_permissions=[],
+                users_permissions=[],
+                collections_permissions=[],
+                roles_permissions=[],
+                data_permissions=[],
+                backups_permissions=[],
+                nodes_permissions=[],
+                tenants_permissions=[],
+                replicate_permissions=[],
+                groups_permissions=[
+                    GroupsPermissionOutput(
+                        group="MyGroup",
+                        group_type="oidc",
+                        actions={Actions.Groups.READ},
+                    )
+                ],
+            ),
+            32,  # Minimum version for group permissions
+        ),
     ],
 )
 def test_create_role(
@@ -671,3 +735,21 @@ def test_permission_joining(client_factory: ClientFactory) -> None:
 
         finally:
             client.roles.delete(role_name)
+
+
+def test_server_side_batching_with_auth() -> None:
+    collection_name = "TestSSBAuth"
+    with connect_to_local(
+        port=RBAC_PORTS[0], grpc_port=RBAC_PORTS[1], auth_credentials=RBAC_AUTH_CREDS
+    ) as client:
+        if client._connection._weaviate_version.is_lower_than(1, 34, 0):
+            pytest.skip("Server-side batching not supported in Weaviate < 1.34.0")
+        collection = client.collections.create(collection_name)
+        with client.batch.experimental() as batch:
+            batch.add_object(collection_name)
+            batch.add_object(collection_name)
+            batch.add_object(collection_name)
+        try:
+            assert len(collection) == 3
+        finally:
+            client.collections.delete(collection_name)
