@@ -408,13 +408,13 @@ TEST_CONFIG_WITH_VECTORIZER_PARAMETERS = [
     ),
     (
         Configure.Vectorizer.text2vec_jinaai(
-            model="jina-embeddings-v3",
+            model="jina-embeddings-v4",
             vectorize_collection_name=False,
             dimensions=512,
         ),
         {
             "text2vec-jinaai": {
-                "model": "jina-embeddings-v3",
+                "model": "jina-embeddings-v4",
                 "vectorizeClassName": False,
                 "dimensions": 512,
             }
@@ -422,13 +422,13 @@ TEST_CONFIG_WITH_VECTORIZER_PARAMETERS = [
     ),
     (
         Configure.Vectorizer.multi2vec_jinaai(
-            model="jina-clip-v2",
+            model="jina-embeddings-v4",
             dimensions=512,
             vectorize_collection_name=False,
         ),
         {
             "multi2vec-jinaai": {
-                "model": "jina-clip-v2",
+                "model": "jina-embeddings-v4",
                 "dimensions": 512,
             }
         },
@@ -838,6 +838,8 @@ TEST_CONFIG_WITH_GENERATIVE = [
             temperature=0.5,
             top_p=0.5,
             base_url="https://api.openai.com",
+            reasoning_effort="high",
+            verbosity="verbose",
         ),
         {
             "generative-openai": {
@@ -848,6 +850,8 @@ TEST_CONFIG_WITH_GENERATIVE = [
                 "temperatureProperty": 0.5,
                 "topPProperty": 0.5,
                 "baseURL": "https://api.openai.com/",
+                "reasoningEffort": "high",
+                "verbosity": "verbose",
             }
         },
     ),
@@ -1039,6 +1043,34 @@ TEST_CONFIG_WITH_GENERATIVE = [
             }
         },
     ),
+    (
+        Configure.Generative.contextualai(),
+        {
+            "generative-contextualai": {},
+        },
+    ),
+    (
+        Configure.Generative.contextualai(
+            model="v2",
+            temperature=0.7,
+            top_p=0.9,
+            max_new_tokens=512,
+            system_prompt="You are a helpful assistant that provides accurate and informative responses based on the given context.",
+            avoid_commentary=False,
+            knowledge=["fact1", "fact2"],
+        ),
+        {
+            "generative-contextualai": {
+                "model": "v2",
+                "temperature": 0.7,
+                "topP": 0.9,
+                "maxNewTokens": 512,
+                "systemPrompt": "You are a helpful assistant that provides accurate and informative responses based on the given context.",
+                "avoidCommentary": False,
+                "knowledge": ["fact1", "fact2"],
+            }
+        },
+    ),
 ]
 
 
@@ -1121,6 +1153,26 @@ TEST_CONFIG_WITH_RERANKER = [
             "reranker-transformers": {},
         },
     ),
+    (
+        Configure.Reranker.contextualai(),
+        {
+            "reranker-contextualai": {},
+        },
+    ),
+    (
+        Configure.Reranker.contextualai(
+            model="ctxl-rerank-v2-instruct-multilingual",
+            instruction="Prioritize recent documents",
+            top_n=5,
+        ),
+        {
+            "reranker-contextualai": {
+                "model": "ctxl-rerank-v2-instruct-multilingual",
+                "instruction": "Prioritize recent documents",
+                "topN": 5,
+            }
+        },
+    ),
 ]
 
 
@@ -1945,13 +1997,23 @@ TEST_CONFIG_WITH_VECTORS_PARAMETERS = [
         },
     ),
     (
-        [Configure.Vectors.text2vec_cohere(name="test", source_properties=["prop"])],
+        [
+            Configure.Vectors.multi2vec_aws(
+                name="test",
+                dimensions=512,
+                model="model",
+                text_fields=["prop"],
+                image_fields=["img"],
+            )
+        ],
         {
             "test": {
                 "vectorizer": {
-                    "text2vec-cohere": {
-                        "vectorizeClassName": True,
-                        "properties": ["prop"],
+                    "multi2vec-aws": {
+                        "textFields": ["prop"],
+                        "imageFields": ["img"],
+                        "model": "model",
+                        "dimensions": 512,
                     }
                 },
                 "vectorIndexType": "hnsw",
@@ -1959,12 +2021,32 @@ TEST_CONFIG_WITH_VECTORS_PARAMETERS = [
         },
     ),
     (
-        [Configure.Vectors.multi2vec_cohere(name="test", text_fields=["prop"])],
+        [
+            Configure.Vectors.text2vec_cohere(
+                name="test", source_properties=["prop"], dimensions=512
+            )
+        ],
+        {
+            "test": {
+                "vectorizer": {
+                    "text2vec-cohere": {
+                        "vectorizeClassName": True,
+                        "properties": ["prop"],
+                        "dimensions": 512,
+                    }
+                },
+                "vectorIndexType": "hnsw",
+            }
+        },
+    ),
+    (
+        [Configure.Vectors.multi2vec_cohere(name="test", text_fields=["prop"], dimensions=512)],
         {
             "test": {
                 "vectorizer": {
                     "multi2vec-cohere": {
                         "textFields": ["prop"],
+                        "dimensions": 512,
                     }
                 },
                 "vectorIndexType": "hnsw",
@@ -2060,7 +2142,7 @@ TEST_CONFIG_WITH_VECTORS_PARAMETERS = [
     (
         [
             Configure.Vectors.text2vec_aws(
-                name="test", region="us-east-1", source_properties=["prop"]
+                name="test", region="us-east-1", source_properties=["prop"], model="model"
             )
         ],
         {
@@ -2071,6 +2153,7 @@ TEST_CONFIG_WITH_VECTORS_PARAMETERS = [
                         "vectorizeClassName": True,
                         "region": "us-east-1",
                         "service": "bedrock",
+                        "model": "model",
                     }
                 },
                 "vectorIndexType": "hnsw",
@@ -2153,6 +2236,20 @@ TEST_CONFIG_WITH_VECTORS_PARAMETERS = [
             }
         },
     ),
+    (
+        [Configure.Vectors.text2vec_morph(name="test", source_properties=["prop"])],
+        {
+            "test": {
+                "vectorizer": {
+                    "text2vec-morph": {
+                        "vectorizeClassName": True,
+                        "properties": ["prop"],
+                    }
+                },
+                "vectorIndexType": "hnsw",
+            }
+        },
+    ),
     (
         [
             Configure.Vectors.text2vec_google(
@@ -2213,10 +2310,24 @@ TEST_CONFIG_WITH_VECTORS_PARAMETERS = [
             }
         },
     ),
+    (
+        [Configure.Vectors.text2vec_model2vec(name="test", source_properties=["prop"])],
+        {
+            "test": {
+                "vectorizer": {
+                    "text2vec-model2vec": {
+                        "properties": ["prop"],
+                        "vectorizeClassName": True,
+                    }
+                },
+                "vectorIndexType": "hnsw",
+            }
+        },
+    ),
     (
         [
             Configure.Vectors.text2vec_voyageai(
-                name="test", source_properties=["prop"], truncate=True
+                name="test", source_properties=["prop"], truncate=True, dimensions=256
             )
         ],
         {
@@ -2226,6 +2337,7 @@ TEST_CONFIG_WITH_VECTORS_PARAMETERS = [
                         "properties": ["prop"],
                         "vectorizeClassName": True,
                         "truncate": True,
+                        "dimensions": 256,
                     }
                 },
                 "vectorIndexType": "hnsw",
