@@ -1,3 +1,4 @@
+from datetime import datetime
 from enum import Enum
 from typing import Any, Dict, List, Optional, cast
 
@@ -19,6 +20,10 @@ class BackupCompressionLevel(str, Enum):
     DEFAULT = "DefaultCompression"
     BEST_SPEED = "BestSpeed"
     BEST_COMPRESSION = "BestCompression"
+    ZSTD_BEST_SPEED = "ZstdBestSpeed"
+    ZSTD_DEFAULT = "ZstdDefaultCompression"
+    ZSTD_BEST_COMPRESSION = "ZstdBestCompression"
+    NO_COMPRESSION = "NoCompression"
 
 
 class BackupStorage(str, Enum):
@@ -57,7 +62,12 @@ class _BackupConfigBase(BaseModel):
 class BackupConfigCreate(_BackupConfigBase):
     """Options to configure the backup when creating a backup."""
 
-    ChunkSize: Optional[int] = Field(default=None, alias="chunk_size")
+    ChunkSize: Optional[int] = Field(
+        default=None,
+        alias="chunk_size",
+        description="DEPRECATED: This parameter no longer has any effect.",
+        exclude=True,
+    )
     CompressionLevel: Optional[BackupCompressionLevel] = Field(
         default=None, alias="compression_level"
     )
@@ -80,3 +90,14 @@ class BackupReturn(BackupStatusReturn):
     """Return type of the backup creation and restore methods."""
 
     collections: List[str] = Field(default_factory=list, alias="classes")
+
+
+class BackupListReturn(BaseModel):
+    """Return type of the backup list method."""
+
+    collections: List[str] = Field(default_factory=list, alias="classes")
+    status: BackupStatus
+    backup_id: str = Field(alias="id")
+    started_at: Optional[datetime] = Field(alias="startedAt", default=None)
+    completed_at: Optional[datetime] = Field(alias="completedAt", default=None)
+    size: float = Field(default=0)
