@@ -10,6 +10,7 @@ from weaviate.backup.backup import (
     STORAGE_NAMES,
     BackupConfigCreate,
     BackupConfigRestore,
+    BackupListReturn,
     BackupReturn,
     BackupStatus,
     BackupStatusReturn,
@@ -27,12 +28,12 @@ from weaviate.exceptions import (
     BackupCanceledError,
     BackupFailedException,
     EmptyResponseException,
-    WeaviateInvalidInputError,
     WeaviateUnsupportedFeatureError,
 )
 from weaviate.util import (
     _capitalize_first_letter,
     _decode_json_response_dict,
+    _decode_json_response_list,
 )
 
 
@@ -91,16 +92,6 @@ class _BackupExecutor(Generic[ConnectionType]):
         }
 
         if config is not None:
-            if self._connection._weaviate_version.is_lower_than(1, 25, 0):
-                raise WeaviateUnsupportedFeatureError(
-                    "BackupConfigCreate",
-                    str(self._connection._weaviate_version),
-                    "1.25.0",
-                )
-            if not isinstance(config, BackupConfigCreate):
-                raise WeaviateInvalidInputError(
-                    f"Expected 'config' to be of type 'BackupConfigCreate', but got {type(config)}."
-                )
             payload["config"] = config._to_dict()
 
         if backup_location is not None:
@@ -244,6 +235,7 @@ class _BackupExecutor(Generic[ConnectionType]):
         wait_for_completion: bool = False,
         config: Optional[BackupConfigRestore] = None,
         backup_location: Optional[BackupLocationType] = None,
+        overwrite_alias: bool = False,
     ) -> executor.Result[BackupReturn]:
         """Restore a backup of all/per collection Weaviate objects.
 
@@ -258,6 +250,7 @@ class _BackupExecutor(Generic[ConnectionType]):
             wait_for_completion: Whether to wait until the backup restore is done.
             config: The configuration of the backup restoration. By default None.
             backup_location: The dynamic location of a backup. By default None.
+            overwrite_alias: Allows ovewriting the collection alias if there is a conflict.
 
         Returns:
             A `BackupReturn` object that contains the backup restore response.
@@ -282,16 +275,10 @@ class _BackupExecutor(Generic[ConnectionType]):
         payload: dict = {
             "include": include_collections,
             "exclude": exclude_collections,
+            "overwriteAlias": overwrite_alias,
         }
         configPayload = {}
         if config is not None:
-            if self._connection._weaviate_version.is_lower_than(1, 25, 0):
-                raise WeaviateUnsupportedFeatureError(
-                    "BackupConfigRestore",
-                    str(self._connection._weaviate_version),
-                    "1.25.0",
-                )
-
             configPayload = config._to_dict()
 
         if backup_location is not None:
@@ -484,21 +471,32 @@ class _BackupExecutor(Generic[ConnectionType]):
             path=path,
             params=params,
             error_msg="Backup cancel failed due to connection error.",
-            status_codes=_ExpectedStatusCodes(ok_in=[204, 404], error="delete object"),
+            status_codes=_ExpectedStatusCodes(ok_in=[204, 404], error="cancel backup"),
         )
 
-    # did not make it into 1.27, will come later
-    # async def list_backups(self, backend: BackupStorage) -> List[BackupReturn]:
-    #     _, backend = _get_and_validate_get_status(backend=backend, backup_id="dummy")
-    #     path = f"/backups/{backend.value}"
+    def list_backups(
+        self, backend: BackupStorage, sort_by_starting_time_asc: Optional[bool] = None
+    ) -> executor.Result[List[BackupListReturn]]:
+        _, backend = _get_and_validate_get_status(backend=backend, backup_id="dummy")
+        path = f"/backups/{backend.value}"
+        params = {}
+        if sort_by_starting_time_asc:
+            params["order"] = "asc"
 
-    #     response = await self._connection.get(
-    #         path=path, error_msg="Backup list status failed due to connection error."
-    #     )
-    #     typed_response = _decode_json_response_list(response, "Backup list")
-    #     if typed_response is None:
-    #         raise EmptyResponseException()
-    #     return [BackupReturn(**entry) for entry in typed_response]
+        def resp(res: Response) -> List[BackupListReturn]:
+            typed_response = _decode_json_response_list(res, "Backup list")
+            if typed_response is None:
+                raise EmptyResponseException()
+            return [BackupListReturn(**entry) for entry in typed_response]
+
+        return executor.execute(
+            response_callback=resp,
+            method=self._connection.get,
+            params=params,
+            path=path,
+            error_msg="Backup listing failed due to connection error.",
+            status_codes=_ExpectedStatusCodes(ok_in=[200], error="list backup"),
+        )
 
 
 def _get_and_validate_create_restore_arguments(
