@@ -1,4 +1,5 @@
 from weaviate.collections.classes.data import DataObject, DataReference
+from weaviate.collections.classes.internal import ReferenceToMulti
 from weaviate.collections.classes.types import GeoCoordinate, PhoneNumber
 
 __all__ = [
@@ -6,4 +7,5 @@ __all__ = [
     "DataReference",
     "GeoCoordinate",
     "PhoneNumber",
+    "ReferenceToMulti",
 ]
