@@ -50,17 +50,16 @@ from weaviate.collections.classes.config_vector_index import (
 from weaviate.collections.classes.config_vector_index import (
     VectorIndexType as VectorIndexTypeAlias,
 )
-from weaviate.collections.classes.config_vectorizers import (
-    CohereModel,
-    _Vectorizer,
-    _VectorizerConfigCreate,
-)
 from weaviate.collections.classes.config_vectorizers import (
     VectorDistances as VectorDistancesAlias,
 )
 from weaviate.collections.classes.config_vectorizers import (
     Vectorizers as VectorizersAlias,
 )
+from weaviate.collections.classes.config_vectorizers import (
+    _Vectorizer,
+    _VectorizerConfigCreate,
+)
 from weaviate.collections.classes.config_vectors import (
     _MultiVectors,
     _VectorConfigCreate,
@@ -83,6 +82,19 @@ AWSService: TypeAlias = Literal[
     "sagemaker",
 ]
 
+OpenAiVerbosity: TypeAlias = Literal[
+    "low",
+    "medium",
+    "high",
+]
+
+OpenAiReasoningEffort: TypeAlias = Literal[
+    "minimal",
+    "low",
+    "medium",
+    "high",
+]
+
 
 class ConsistencyLevel(str, BaseEnum):
     """The consistency levels when writing to Weaviate with replication enabled.
@@ -152,6 +164,7 @@ class Tokenization(str, BaseEnum):
         TRIGRAM: Tokenize into trigrams.
         KAGOME_JA: Tokenize using the 'Kagome' tokenizer (for Japanese).
         KAGOME_KR: Tokenize using the 'Kagome' tokenizer and a Korean MeCab dictionary (for Korean).
+        GSE_CH: Tokenize using GSE (for Chinese).
     """
 
     WORD = "word"
@@ -162,6 +175,7 @@ class Tokenization(str, BaseEnum):
     TRIGRAM = "trigram"
     KAGOME_JA = "kagome_ja"
     KAGOME_KR = "kagome_kr"
+    GSE_CH = "gse_ch"
 
 
 class GenerativeSearches(str, BaseEnum):
@@ -175,6 +189,7 @@ class GenerativeSearches(str, BaseEnum):
         ANTHROPIC: Weaviate module backed by Anthropic generative models.
         ANYSCALE: Weaviate module backed by Anyscale generative models.
         COHERE: Weaviate module backed by Cohere generative models.
+        CONTEXTUALAI: Weaviate module backed by ContextualAI generative models.
         DATABRICKS: Weaviate module backed by Databricks generative models.
         FRIENDLIAI: Weaviate module backed by FriendliAI generative models.
         MISTRAL: Weaviate module backed by Mistral generative models.
@@ -188,6 +203,7 @@ class GenerativeSearches(str, BaseEnum):
     ANTHROPIC = "generative-anthropic"
     ANYSCALE = "generative-anyscale"
     COHERE = "generative-cohere"
+    CONTEXTUALAI = "generative-contextualai"
     DATABRICKS = "generative-databricks"
     DUMMY = "generative-dummy"
     FRIENDLIAI = "generative-friendliai"
@@ -208,6 +224,7 @@ class Rerankers(str, BaseEnum):
     Attributes:
         NONE: No reranker.
         COHERE: Weaviate module backed by Cohere reranking models.
+        CONTEXTUALAI: Weaviate module backed by ContextualAI reranking models.
         TRANSFORMERS: Weaviate module backed by Transformers reranking models.
         VOYAGEAI: Weaviate module backed by VoyageAI reranking models.
         JINAAI: Weaviate module backed by JinaAI reranking models.
@@ -216,6 +233,7 @@ class Rerankers(str, BaseEnum):
 
     NONE = "none"
     COHERE = "reranker-cohere"
+    CONTEXTUALAI = "reranker-contextualai"
     TRANSFORMERS = "reranker-transformers"
     VOYAGEAI = "reranker-voyageai"
     JINAAI = "reranker-jinaai"
@@ -417,6 +435,8 @@ class _GenerativeOpenAIConfigBase(_GenerativeProvider):
 
 class _GenerativeOpenAIConfig(_GenerativeOpenAIConfigBase):
     model: Optional[str]
+    verbosity: Optional[str]
+    reasoningEffort: Optional[str]
 
 
 class _GenerativeAzureOpenAIConfig(_GenerativeOpenAIConfigBase):
@@ -443,6 +463,19 @@ class _GenerativeCohereConfig(_GenerativeProvider):
         return ret_dict
 
 
+class _GenerativeContextualAIConfig(_GenerativeProvider):
+    generative: Union[GenerativeSearches, _EnumLikeStr] = Field(
+        default=GenerativeSearches.CONTEXTUALAI, frozen=True, exclude=True
+    )
+    model: Optional[str]
+    temperature: Optional[float]
+    topP: Optional[float]
+    maxNewTokens: Optional[int]
+    systemPrompt: Optional[str]
+    avoidCommentary: Optional[bool]
+    knowledge: Optional[List[str]]
+
+
 class _GenerativeGoogleConfig(_GenerativeProvider):
     generative: Union[GenerativeSearches, _EnumLikeStr] = Field(
         default=GenerativeSearches.PALM, frozen=True, exclude=True
@@ -464,6 +497,7 @@ class _GenerativeAWSConfig(_GenerativeProvider):
     service: str
     model: Optional[str]
     endpoint: Optional[str]
+    maxTokens: Optional[int]
 
 
 class _GenerativeAnthropicConfig(_GenerativeProvider):
@@ -547,6 +581,22 @@ class _RerankerNvidiaConfig(_RerankerProvider):
         return ret_dict
 
 
+RerankerContextualAIModel = Literal[
+    "ctxl-rerank-v2-instruct-multilingual",
+    "ctxl-rerank-v2-instruct-multilingual-mini",
+    "ctxl-rerank-v1-instruct",
+]
+
+
+class _RerankerContextualAIConfig(_RerankerProvider):
+    reranker: Union[Rerankers, _EnumLikeStr] = Field(
+        default=Rerankers.CONTEXTUALAI, frozen=True, exclude=True
+    )
+    model: Optional[Union[RerankerContextualAIModel, str]] = Field(default=None)
+    instruction: Optional[str] = Field(default=None)
+    topN: Optional[int] = Field(default=None)
+
+
 class _Generative:
     """Use this factory class to create the correct object for the `generative_config` argument in the `collections.create()` method.
 
@@ -711,6 +761,9 @@ class _Generative:
         temperature: Optional[float] = None,
         top_p: Optional[float] = None,
         base_url: Optional[AnyHttpUrl] = None,
+        *,
+        verbosity: Optional[Union[OpenAiVerbosity, str]] = None,
+        reasoning_effort: Optional[Union[OpenAiReasoningEffort, str]] = None,
     ) -> _GenerativeProvider:
         """Create a `_GenerativeOpenAIConfig` object for use when performing AI generation using the `generative-openai` module.
 
@@ -725,6 +778,8 @@ class _Generative:
             temperature: The temperature to use. Defaults to `None`, which uses the server-defined default
             top_p: The top P to use. Defaults to `None`, which uses the server-defined default
             base_url: The base URL where the API request should go. Defaults to `None`, which uses the server-defined default
+            verbosity: The verbosity level to use. One of 'low', 'medium', 'high'. Defaults to `None`, which uses the server-defined default
+            reasoning_effort: The reasoning effort level to use. One of 'minimal', 'low
         """
         return _GenerativeOpenAIConfig(
             baseURL=base_url,
@@ -734,6 +789,8 @@ class _Generative:
             presencePenaltyProperty=presence_penalty,
             temperatureProperty=temperature,
             topPProperty=top_p,
+            verbosity=verbosity,
+            reasoningEffort=reasoning_effort,
         )
 
     @staticmethod
@@ -775,7 +832,7 @@ class _Generative:
 
     @staticmethod
     def cohere(
-        model: Optional[Union[CohereModel, str]] = None,
+        model: Optional[str] = None,
         k: Optional[int] = None,
         max_tokens: Optional[int] = None,
         return_likelihoods: Optional[str] = None,
@@ -807,6 +864,40 @@ class _Generative:
             temperatureProperty=temperature,
         )
 
+    @staticmethod
+    def contextualai(
+        model: Optional[str] = None,
+        max_new_tokens: Optional[int] = None,
+        temperature: Optional[float] = None,
+        top_p: Optional[float] = None,
+        system_prompt: Optional[str] = None,
+        avoid_commentary: Optional[bool] = None,
+        knowledge: Optional[List[str]] = None,
+    ) -> _GenerativeProvider:
+        """Create a `_GenerativeContextualAIConfig` object for use when performing AI generation using the `generative-contextualai` module.
+
+        See the [documentation](https://weaviate.io/developers/weaviate/model-providers/contextualai/generative)
+        for detailed usage.
+
+        Args:
+            model: The model to use. Defaults to `None`, which uses the server-defined default
+            max_new_tokens: The maximum number of tokens to generate. Defaults to `None`, which uses the server-defined default
+            temperature: The temperature to use. Defaults to `None`, which uses the server-defined default
+            top_p: Nucleus sampling parameter (0 < x <= 1). Defaults to `None`, which uses the server-defined default
+            system_prompt: System instructions the model follows. Defaults to `None`, which uses the server-defined default
+            avoid_commentary: If `True`, reduce conversational commentary in responses. Defaults to `None`, which uses the server-defined default
+            knowledge: Additional detailed knowledge sources with varied information. Defaults to `None`, which uses the server-defined default
+        """
+        return _GenerativeContextualAIConfig(
+            model=model,
+            temperature=temperature,
+            topP=top_p,
+            maxNewTokens=max_new_tokens,
+            systemPrompt=system_prompt,
+            avoidCommentary=avoid_commentary,
+            knowledge=knowledge,
+        )
+
     @staticmethod
     @docstring_deprecated(
         deprecated_in="4.9.0",
@@ -891,6 +982,7 @@ This method is deprecated and will be removed in Q2 '25. Please use :meth:`~weav
         region: str = "",  # cant have a non-default value after a default value, but we cant change the order for BC
         endpoint: Optional[str] = None,
         service: Union[AWSService, str] = "bedrock",
+        max_tokens: Optional[int] = None,
     ) -> _GenerativeProvider:
         """Create a `_GenerativeAWSConfig` object for use when performing AI generation using the `generative-aws` module.
 
@@ -899,15 +991,13 @@ This method is deprecated and will be removed in Q2 '25. Please use :meth:`~weav
 
         Args:
             model: The model to use, REQUIRED for service "bedrock".
+            max_tokens: The maximum number of tokens to generate. Defaults to `None`, which uses the server-defined default.
             region: The AWS region to run the model from, REQUIRED.
             endpoint: The model to use, REQUIRED for service "sagemaker".
             service: The AWS service to use, options are "bedrock" and "sagemaker".
         """
         return _GenerativeAWSConfig(
-            model=model,
-            region=region,
-            service=service,
-            endpoint=endpoint,
+            model=model, region=region, service=service, endpoint=endpoint, maxTokens=max_tokens
         )
 
     @staticmethod
@@ -1027,6 +1117,24 @@ class _Reranker:
         """
         return _RerankerNvidiaConfig(model=model, baseURL=base_url)
 
+    @staticmethod
+    def contextualai(
+        model: Optional[str] = None,
+        instruction: Optional[str] = None,
+        top_n: Optional[int] = None,
+    ) -> _RerankerProvider:
+        """Create a `_RerankerContextualAIConfig` object for use when reranking using the `reranker-contextualai` module.
+
+        See the [documentation](https://weaviate.io/developers/weaviate/model-providers/contextualai/reranker)
+        for detailed usage.
+
+        Args:
+            model: The model to use. Defaults to `None`, which uses the server-defined default
+            instruction: Custom instructions for reranking. Defaults to `None`.
+            top_n: Number of top results to return. Defaults to `None`, which uses the server-defined default.
+        """
+        return _RerankerContextualAIConfig(model=model, instruction=instruction, topN=top_n)
+
 
 class _CollectionConfigCreateBase(_ConfigCreateModel):
     description: Optional[str] = Field(default=None)
@@ -1500,6 +1608,7 @@ class _SQConfig(_ConfigBase):
 
 @dataclass
 class _RQConfig(_ConfigBase):
+    cache: Optional[bool]
     bits: Optional[int]
     rescore_limit: int
 
@@ -2223,6 +2332,7 @@ class _VectorIndexQuantizerUpdate:
     def rq(
         rescore_limit: Optional[int] = None,
         enabled: bool = True,
+        bits: Optional[int] = None,
     ) -> _RQConfigUpdate:
         """Create a `_RQConfigUpdate` object to be used when updating the Rotational quantization (RQ) configuration of Weaviate.
 
@@ -2231,7 +2341,7 @@ class _VectorIndexQuantizerUpdate:
         Arguments:
             See [the docs](https://weaviate.io/developers/weaviate/concepts/vector-index#hnsw-with-compression) for a more detailed view!
         """  # noqa: D417 (missing argument descriptions in the docstring)
-        return _RQConfigUpdate(enabled=enabled, rescoreLimit=rescore_limit)
+        return _RQConfigUpdate(enabled=enabled, rescoreLimit=rescore_limit, bits=bits)
 
 
 class _VectorIndexUpdate:
@@ -2271,7 +2381,7 @@ class _VectorIndexUpdate:
     @staticmethod
     def flat(
         vector_cache_max_objects: Optional[int] = None,
-        quantizer: Optional[_BQConfigUpdate] = None,
+        quantizer: Optional[Union[_BQConfigUpdate, _RQConfigUpdate]] = None,
     ) -> _VectorIndexConfigFlatUpdate:
         """Create an `_VectorIndexConfigFlatUpdate` object to update the configuration of the FLAT vector index.
 
