@@ -80,7 +80,10 @@ class _VectorIndexConfigCreate(_ConfigCreateModel):
     def _to_dict(self) -> Dict[str, Any]:
         ret_dict = super()._to_dict()
         if self.quantizer is not None:
-            ret_dict[self.quantizer.quantizer_name()] = self.quantizer._to_dict()
+            if isinstance(self.quantizer, _UncompressedConfigCreate):
+                ret_dict[self.quantizer.quantizer_name()] = True
+            else:
+                ret_dict[self.quantizer.quantizer_name()] = self.quantizer._to_dict()
         if self.distance is not None:
             ret_dict["distance"] = str(self.distance.value)
         if self.multivector is not None and self.multivector.encoding is not None:
@@ -272,6 +275,7 @@ class _SQConfigCreate(_QuantizerConfigCreate):
 
 
 class _RQConfigCreate(_QuantizerConfigCreate):
+    cache: Optional[bool]
     bits: Optional[int]
     rescoreLimit: Optional[int]
 
@@ -280,6 +284,12 @@ class _RQConfigCreate(_QuantizerConfigCreate):
         return "rq"
 
 
+class _UncompressedConfigCreate(_QuantizerConfigCreate):
+    @staticmethod
+    def quantizer_name() -> str:
+        return "skipDefaultQuantization"
+
+
 class _PQConfigUpdate(_QuantizerConfigUpdate):
     bitCompression: Optional[bool] = Field(default=None)
     centroids: Optional[int]
@@ -305,6 +315,7 @@ class _BQConfigUpdate(_QuantizerConfigUpdate):
 class _RQConfigUpdate(_QuantizerConfigUpdate):
     enabled: Optional[bool]
     rescoreLimit: Optional[int]
+    bits: Optional[int]
 
     @staticmethod
     def quantizer_name() -> str:
@@ -433,6 +444,7 @@ class _VectorIndexQuantizer:
 
     @staticmethod
     def rq(
+        cache: Optional[bool] = None,
         bits: Optional[int] = None,
         rescore_limit: Optional[int] = None,
     ) -> _RQConfigCreate:
@@ -444,10 +456,16 @@ class _VectorIndexQuantizer:
             See [the docs](https://weaviate.io/developers/weaviate/concepts/vector-index) for a more detailed view!
         """  # noqa: D417 (missing argument descriptions in the docstring)
         return _RQConfigCreate(
+            cache=cache,
             bits=bits,
             rescoreLimit=rescore_limit,
         )
 
+    @staticmethod
+    def none() -> _UncompressedConfigCreate:
+        """Create a a vector index without compression."""
+        return _UncompressedConfigCreate()
+
 
 class _VectorIndex:
     MultiVector = _VectorIndexMultiVector
