@@ -44,16 +44,16 @@ JinaModel: TypeAlias = Literal[
     "jina-embeddings-v2-base-es",
     "jina-embeddings-v2-base-code",
     "jina-embeddings-v3",
+    "jina-embeddings-v4",
 ]
-JinaMultimodalModel: TypeAlias = Literal[
-    "jina-clip-v1",
-    "jina-clip-v2",
-]
+JinaMultimodalModel: TypeAlias = Literal["jina-clip-v1", "jina-clip-v2", "jina-embeddings-v4"]
 VoyageModel: TypeAlias = Literal[
     "voyage-3.5",
     "voyage-3.5-lite",
+    "voyage-3-large",
     "voyage-3",
     "voyage-3-lite",
+    "voyage-context-3",
     "voyage-large-2",
     "voyage-code-2",
     "voyage-2",
@@ -115,6 +115,8 @@ class Vectorizers(str, Enum):
     TEXT2VEC_GPT4ALL = "text2vec-gpt4all"
     TEXT2VEC_HUGGINGFACE = "text2vec-huggingface"
     TEXT2VEC_MISTRAL = "text2vec-mistral"
+    TEXT2VEC_MORPH = "text2vec-morph"
+    TEXT2VEC_MODEL2VEC = "text2vec-model2vec"
     TEXT2VEC_NVIDIA = "text2vec-nvidia"
     TEXT2VEC_OLLAMA = "text2vec-ollama"
     TEXT2VEC_OPENAI = "text2vec-openai"
@@ -124,6 +126,7 @@ class Vectorizers(str, Enum):
     TEXT2VEC_VOYAGEAI = "text2vec-voyageai"
     TEXT2VEC_WEAVIATE = "text2vec-weaviate"
     IMG2VEC_NEURAL = "img2vec-neural"
+    MULTI2VEC_AWS = "multi2vec-aws"
     MULTI2VEC_CLIP = "multi2vec-clip"
     MULTI2VEC_COHERE = "multi2vec-cohere"
     MULTI2VEC_JINAAI = "multi2vec-jinaai"
@@ -176,6 +179,14 @@ class _Text2VecContextionaryConfig(_VectorizerConfigCreate):
     vectorizeClassName: bool
 
 
+class _Text2VecModel2VecConfig(_VectorizerConfigCreate):
+    vectorizer: Union[Vectorizers, _EnumLikeStr] = Field(
+        default=Vectorizers.TEXT2VEC_MODEL2VEC, frozen=True, exclude=True
+    )
+    vectorizeClassName: bool
+    inferenceUrl: Optional[str]
+
+
 class _VectorizerCustomConfig(_VectorizerConfigCreate):
     module_config: Optional[Dict[str, Any]]
 
@@ -265,6 +276,21 @@ class _Text2VecMistralConfig(_VectorizerConfigCreate):
         return ret_dict
 
 
+class _Text2VecMorphConfig(_VectorizerConfigCreate):
+    vectorizer: Union[Vectorizers, _EnumLikeStr] = Field(
+        default=Vectorizers.TEXT2VEC_MORPH, frozen=True, exclude=True
+    )
+    model: Optional[str]
+    vectorizeClassName: bool
+    baseURL: Optional[AnyHttpUrl]
+
+    def _to_dict(self) -> Dict[str, Any]:
+        ret_dict = super()._to_dict()
+        if self.baseURL is not None:
+            ret_dict["baseURL"] = self.baseURL.unicode_string()
+        return ret_dict
+
+
 class _Text2VecDatabricksConfig(_VectorizerConfigCreate):
     vectorizer: Union[Vectorizers, _EnumLikeStr] = Field(
         default=Vectorizers.TEXT2VEC_DATABRICKS, frozen=True, exclude=True
@@ -304,6 +330,7 @@ class _Text2VecCohereConfig(_VectorizerConfigCreate):
     )
     baseURL: Optional[AnyHttpUrl]
     model: Optional[str]
+    dimensions: Optional[int]
     truncate: Optional[CohereTruncation]
     vectorizeClassName: bool
 
@@ -335,6 +362,7 @@ class _Text2VecTransformersConfig(_VectorizerConfigCreate):
     inferenceUrl: Optional[str]
     passageInferenceUrl: Optional[str]
     queryInferenceUrl: Optional[str]
+    dimensions: Optional[int] = None
 
 
 class _Text2VecGPT4AllConfig(_VectorizerConfigCreate):
@@ -358,6 +386,7 @@ class _Text2VecVoyageConfig(_VectorizerConfigCreate):
     vectorizer: Union[Vectorizers, _EnumLikeStr] = Field(
         default=Vectorizers.TEXT2VEC_VOYAGEAI, frozen=True, exclude=True
     )
+    dimensions: Optional[int]
     model: Optional[str]
     baseURL: Optional[str]
     truncate: Optional[bool]
@@ -433,6 +462,7 @@ class _Multi2VecCohereConfig(_Multi2VecBase):
     )
     baseURL: Optional[AnyHttpUrl]
     model: Optional[str]
+    dimensions: Optional[int]
     truncate: Optional[CohereTruncation]
 
     def _to_dict(self) -> Dict[str, Any]:
@@ -457,6 +487,15 @@ class _Multi2VecJinaConfig(_Multi2VecBase):
         return ret_dict
 
 
+class _Multi2VecAWSConfig(_Multi2VecBase):
+    vectorizer: Union[Vectorizers, _EnumLikeStr] = Field(
+        default=Vectorizers.MULTI2VEC_AWS, frozen=True, exclude=True
+    )
+    region: Optional[str]
+    model: Optional[str]
+    dimensions: Optional[int]
+
+
 class _Multi2MultiVecJinaConfig(_Multi2VecBase):
     vectorizer: Union[Vectorizers, _EnumLikeStr] = Field(
         default=Vectorizers.MULTI2MULTI_JINAAI, frozen=True, exclude=True
@@ -794,6 +833,7 @@ class _Vectorizer:
         return _Text2VecCohereConfig(
             baseURL=base_url,
             model=model,
+            dimensions=None,
             truncate=truncate,
             vectorizeClassName=vectorize_collection_name,
         )
@@ -827,6 +867,7 @@ class _Vectorizer:
         return _Multi2VecCohereConfig(
             baseURL=base_url,
             model=model,
+            dimensions=None,
             truncate=truncate,
             imageFields=_map_multi2vec_fields(image_fields),
             textFields=_map_multi2vec_fields(text_fields),
@@ -1268,6 +1309,7 @@ This method is deprecated and will be removed in Q2 '25. Please use :meth:`~weav
     @staticmethod
     def text2vec_transformers(
         pooling_strategy: Literal["masked_mean", "cls"] = "masked_mean",
+        dimensions: Optional[int] = None,
         vectorize_collection_name: bool = True,
         inference_url: Optional[str] = None,
         passage_inference_url: Optional[str] = None,
@@ -1280,6 +1322,7 @@ This method is deprecated and will be removed in Q2 '25. Please use :meth:`~weav
 
         Args:
             pooling_strategy: The pooling strategy to use. Defaults to `masked_mean`.
+            dimensions: The number of dimensions for the generated embeddings. Defaults to `None`, which uses the server-defined default.
             vectorize_collection_name: Whether to vectorize the collection name. Defaults to `True`.
             inference_url: The inference url to use where API requests should go. You can use either this OR passage/query_inference_url. Defaults to `None`, which uses the server-defined default.
             passage_inference_url: The inference url to use where passage API requests should go. You can use either this and query_inference_url OR inference_url. Defaults to `None`, which uses the server-defined default.
@@ -1290,6 +1333,7 @@ This method is deprecated and will be removed in Q2 '25. Please use :meth:`~weav
         """
         return _Text2VecTransformersConfig(
             poolingStrategy=pooling_strategy,
+            dimensions=dimensions,
             vectorizeClassName=vectorize_collection_name,
             inferenceUrl=inference_url,
             passageInferenceUrl=passage_inference_url,
@@ -1383,6 +1427,7 @@ This method is deprecated and will be removed in Q2 '25. Please use :meth:`~weav
             baseURL=base_url,
             truncate=truncate,
             vectorizeClassName=vectorize_collection_name,
+            dimensions=None,
         )
 
     @staticmethod
@@ -1428,3 +1473,23 @@ This method is deprecated and will be removed in Q2 '25. Please use :meth:`~weav
             truncate=truncate,
             vectorizeClassName=vectorize_collection_name,
         )
+
+    @staticmethod
+    def text2vec_model2vec(
+        *,
+        inference_url: Optional[str] = None,
+        vectorize_collection_name: bool = True,
+    ) -> _VectorizerConfigCreate:
+        """Create a `_Text2VecModel2VecConfigCreate` object for use when vectorizing using the `text2vec-model2vec` model.
+
+        See the [documentation](https://weaviate.io/developers/weaviate/model-providers/model2vec/embeddings)
+        for detailed usage.
+
+        Args:
+            vectorize_collection_name: Whether to vectorize the collection name. Defaults to `True`.
+            inference_url: The inference url to use where API requests should go. Defaults to `None`, which uses the server-defined default.
+        """
+        return _Text2VecModel2VecConfig(
+            vectorizeClassName=vectorize_collection_name,
+            inferenceUrl=inference_url,
+        )
