@@ -1,6 +1,7 @@
 from typing import Any, Dict, List, Literal, Optional, Union
 
 from pydantic import AnyHttpUrl, Field
+from typing_extensions import deprecated as typing_deprecated
 
 from weaviate.collections.classes.config_base import (
     _ConfigCreateModel,
@@ -39,6 +40,7 @@ from weaviate.collections.classes.config_vectorizers import (
     _Img2VecNeuralConfig,
     _map_multi2vec_fields,
     _Multi2MultiVecJinaConfig,
+    _Multi2VecAWSConfig,
     _Multi2VecBindConfig,
     _Multi2VecClipConfig,
     _Multi2VecCohereConfig,
@@ -58,6 +60,8 @@ from weaviate.collections.classes.config_vectorizers import (
     _Text2VecHuggingFaceConfig,
     _Text2VecJinaConfig,
     _Text2VecMistralConfig,
+    _Text2VecModel2VecConfig,
+    _Text2VecMorphConfig,
     _Text2VecNvidiaConfig,
     _Text2VecOllamaConfig,
     _Text2VecOpenAIConfig,
@@ -341,6 +345,7 @@ class _Vectors:
         quantizer: Optional[_QuantizerConfigCreate] = None,
         base_url: Optional[AnyHttpUrl] = None,
         model: Optional[Union[CohereModel, str]] = None,
+        dimensions: Optional[int] = None,
         truncate: Optional[CohereTruncation] = None,
         source_properties: Optional[List[str]] = None,
         vector_index_config: Optional[_VectorIndexConfigCreate] = None,
@@ -356,6 +361,7 @@ class _Vectors:
             quantizer: The quantizer to use for the vector index. If not provided, no quantization will be applied.
             base_url: The base URL to use where API requests should go. Defaults to `None`, which uses the server-defined default.
             model: The model to use. Defaults to `None`, which uses the server-defined default.
+            dimensions: Number of output dimensions. Defaults to `None`, which uses the server-defined default.
             truncate: The truncation strategy to use. Defaults to `None`, which uses the server-defined default.
             source_properties: Which properties should be included when vectorizing. By default all text properties are included.
             vector_index_config: The configuration for Weaviate's vector index. Use `wvc.config.Configure.VectorIndex` to create a vector index configuration. None by default
@@ -370,6 +376,7 @@ class _Vectors:
             vectorizer=_Text2VecCohereConfig(
                 baseURL=base_url,
                 model=model,
+                dimensions=dimensions,
                 truncate=truncate,
                 vectorizeClassName=vectorize_collection_name,
             ),
@@ -384,6 +391,7 @@ class _Vectors:
         base_url: Optional[AnyHttpUrl] = None,
         image_fields: Optional[Union[List[str], List[Multi2VecField]]] = None,
         model: Optional[Union[CohereMultimodalModel, str]] = None,
+        dimensions: Optional[int] = None,
         text_fields: Optional[Union[List[str], List[Multi2VecField]]] = None,
         truncate: Optional[CohereTruncation] = None,
         vector_index_config: Optional[_VectorIndexConfigCreate] = None,
@@ -400,6 +408,7 @@ class _Vectors:
             base_url: The base URL to use where API requests should go. Defaults to `None`, which uses the server-defined default.
             image_fields: The image fields to use in vectorization.
             model: The model to use. Defaults to `None`, which uses the server-defined default.
+            dimensions: Number of output dimensions. Defaults to `None`, which uses the server-defined default.
             text_fields: The text fields to use in vectorization.
             truncate: The truncation strategy to use. Defaults to `None`, which uses the server-defined default.
             vector_index_config: The configuration for Weaviate's vector index. Use `wvc.config.Configure.VectorIndex` to create a vector index configuration. None by default
@@ -412,6 +421,7 @@ class _Vectors:
             vectorizer=_Multi2VecCohereConfig(
                 baseURL=base_url,
                 model=model,
+                dimensions=dimensions,
                 truncate=truncate,
                 imageFields=_map_multi2vec_fields(image_fields),
                 textFields=_map_multi2vec_fields(text_fields),
@@ -420,6 +430,9 @@ class _Vectors:
         )
 
     @staticmethod
+    @typing_deprecated(
+        "The contextionary model is old and not recommended for use. If you are looking for a local, lightweight model try the new text2vec-model2vec module instead."
+    )
     def text2vec_contextionary(
         *,
         name: Optional[str] = None,
@@ -449,6 +462,39 @@ class _Vectors:
             vector_index_config=_IndexWrappers.single(vector_index_config, quantizer),
         )
 
+    @staticmethod
+    def text2vec_model2vec(
+        *,
+        name: Optional[str] = None,
+        quantizer: Optional[_QuantizerConfigCreate] = None,
+        source_properties: Optional[List[str]] = None,
+        vector_index_config: Optional[_VectorIndexConfigCreate] = None,
+        inference_url: Optional[str] = None,
+        vectorize_collection_name: bool = True,
+    ) -> _VectorConfigCreate:
+        """Create a vector using the `text2vec_model2vec` module.
+
+        See the [documentation](https://docs.weaviate.io/weaviate/model-providers/model2vec)
+        for detailed usage.
+
+        Args:
+            name: The name of the vector.
+            inference_url: The inferenceUrl to use where API requests should go. Defaults to `None`, which uses the server-defined default.
+            quantizer: The quantizer to use for the vector index. If not provided, no quantization will be applied.
+            source_properties: Which properties should be included when vectorizing. By default all text properties are included.
+            vector_index_config: The configuration for Weaviate's vector index. Use `wvc.config.Configure.VectorIndex` to create a vector index configuration. None by default
+            vectorize_collection_name: Whether to vectorize the collection name. Defaults to `True`.
+        """
+        return _VectorConfigCreate(
+            name=name,
+            source_properties=source_properties,
+            vectorizer=_Text2VecModel2VecConfig(
+                vectorizeClassName=vectorize_collection_name,
+                inferenceUrl=inference_url,
+            ),
+            vector_index_config=_IndexWrappers.single(vector_index_config, quantizer),
+        )
+
     @staticmethod
     def text2vec_databricks(
         *,
@@ -521,6 +567,42 @@ class _Vectors:
             vector_index_config=_IndexWrappers.single(vector_index_config, quantizer),
         )
 
+    @staticmethod
+    def text2vec_morph(
+        *,
+        name: Optional[str] = None,
+        quantizer: Optional[_QuantizerConfigCreate] = None,
+        base_url: Optional[AnyHttpUrl] = None,
+        model: Optional[str] = None,
+        source_properties: Optional[List[str]] = None,
+        vector_index_config: Optional[_VectorIndexConfigCreate] = None,
+        vectorize_collection_name: bool = True,
+    ) -> _VectorConfigCreate:
+        """Create a vector using the `text2vec-morph` module.
+
+        See the [documentation](https://weaviate.io/developers/weaviate/model-providers/morph/embeddings)
+        for detailed usage.
+
+        Args:
+            name: The name of the vector.
+            quantizer: The quantizer to use for the vector index. If not provided, no quantization will be applied.
+            base_url: The base URL to use where API requests should go. Defaults to `None`, which uses the server-defined default.
+            model: The model to use. Defaults to `None`, which uses the server-defined default.
+            source_properties: Which properties should be included when vectorizing. By default all text properties are included.
+            vector_index_config: The configuration for Weaviate's vector index. Use `wvc.config.Configure.VectorIndex` to create a vector index configuration. None by default
+            vectorize_collection_name: Whether to vectorize the collection name. Defaults to `True`.
+        """
+        return _VectorConfigCreate(
+            name=name,
+            source_properties=source_properties,
+            vectorizer=_Text2VecMorphConfig(
+                baseURL=base_url,
+                model=model,
+                vectorizeClassName=vectorize_collection_name,
+            ),
+            vector_index_config=_IndexWrappers.single(vector_index_config, quantizer),
+        )
+
     @staticmethod
     def text2vec_ollama(
         *,
@@ -614,7 +696,7 @@ class _Vectors:
         name: Optional[str] = None,
         quantizer: Optional[_QuantizerConfigCreate] = None,
         endpoint: Optional[str] = None,
-        model: Optional[Union[AWSModel, str]] = None,
+        model: Optional[Union[AWSModel, str]],
         region: str,
         service: Union[AWSService, str] = "bedrock",
         source_properties: Optional[List[str]] = None,
@@ -630,7 +712,7 @@ class _Vectors:
             name: The name of the vector.
             quantizer: The quantizer to use for the vector index. If not provided, no quantization will be applied.
             endpoint: The endpoint to use. Defaults to `None`, which uses the server-defined default.
-            model: The model to use.
+            model: The model to use, REQUIRED.
             region: The AWS region to run the model from, REQUIRED.
             service: The AWS service to use. Defaults to `bedrock`.
             source_properties: Which properties should be included when vectorizing. By default all text properties are included.
@@ -650,6 +732,48 @@ class _Vectors:
             vector_index_config=_IndexWrappers.single(vector_index_config, quantizer),
         )
 
+    @staticmethod
+    def multi2vec_aws(
+        *,
+        name: Optional[str] = None,
+        quantizer: Optional[_QuantizerConfigCreate] = None,
+        dimensions: Optional[int] = None,
+        image_fields: Optional[Union[List[str], List[Multi2VecField]]] = None,
+        model: Optional[str] = None,
+        text_fields: Optional[Union[List[str], List[Multi2VecField]]] = None,
+        region: Optional[str] = None,
+        vector_index_config: Optional[_VectorIndexConfigCreate] = None,
+    ) -> _VectorConfigCreate:
+        """Create a vector using the `multi2vec-aws` module.
+
+        See the [documentation](https://weaviate.io/developers/weaviate/model-providers/aws/embeddings)
+        for detailed usage.
+
+        Args:
+            name: The name of the vector.
+            quantizer: The quantizer to use for the vector index. If not provided, no quantization will be applied.
+            dimensions: The number of dimensions to use. Defaults to `None`, which uses the server-defined default.
+            image_fields: The image fields to use in vectorization.
+            model: The model to use. Defaults to `None`, which uses the server-defined default.
+            text_fields: The text fields to use in vectorization.
+            region: The AWS region to run the model from. Defaults to `None`, which uses the server-defined defau
+            vector_index_config: The configuration for Weaviate's vector index. Use `wvc.config.Configure.VectorIndex` to create a vector index configuration. None by default
+
+        Raises:
+            pydantic.ValidationError: If `model` is not a valid value from the `JinaMultimodalModel` type.
+        """
+        return _VectorConfigCreate(
+            name=name,
+            vectorizer=_Multi2VecAWSConfig(
+                region=region,
+                model=model,
+                dimensions=dimensions,
+                imageFields=_map_multi2vec_fields(image_fields),
+                textFields=_map_multi2vec_fields(text_fields),
+            ),
+            vector_index_config=_IndexWrappers.single(vector_index_config, quantizer),
+        )
+
     @staticmethod
     def img2vec_neural(
         *,
@@ -966,6 +1090,9 @@ class _Vectors:
         )
 
     @staticmethod
+    @typing_deprecated(
+        "The `text2vec-gpt4all` vectorizer is deprecated and will be removed in a future release. See the docs (https://docs.weaviate.io/weaviate/model-providers) for alternatives."
+    )
     def text2vec_gpt4all(
         *,
         name: Optional[str] = None,
@@ -1147,6 +1274,7 @@ class _Vectors:
     def text2vec_transformers(
         *,
         name: Optional[str] = None,
+        dimensions: Optional[int] = None,
         quantizer: Optional[_QuantizerConfigCreate] = None,
         inference_url: Optional[str] = None,
         passage_inference_url: Optional[str] = None,
@@ -1163,6 +1291,7 @@ class _Vectors:
 
         Args:
             name: The name of the vector.
+            dimensions: The number of dimensions for the generated embeddings. Defaults to `None`, which uses the server-defined default.
             quantizer: The quantizer to use for the vector index. If not provided, no quantization will be applied.
             inference_url: The inferenceUrl to use where API requests should go. You can use either this OR passage/query_inference_url. Defaults to `None`, which uses the server-defined default.
             passage_inference_url: The inferenceUrl to use where passage API requests should go. You can use either this and query_inference_url OR inference_url. Defaults to `None`, which uses the server-defined default.
@@ -1177,6 +1306,7 @@ class _Vectors:
             source_properties=source_properties,
             vectorizer=_Text2VecTransformersConfig(
                 poolingStrategy=pooling_strategy,
+                dimensions=dimensions,
                 vectorizeClassName=vectorize_collection_name,
                 inferenceUrl=inference_url,
                 passageInferenceUrl=passage_inference_url,
@@ -1269,11 +1399,12 @@ class _Vectors:
     def text2vec_voyageai(
         *,
         name: Optional[str] = None,
-        quantizer: Optional[_QuantizerConfigCreate] = None,
         base_url: Optional[str] = None,
+        dimensions: Optional[int] = None,
         model: Optional[Union[VoyageModel, str]] = None,
-        truncate: Optional[bool] = None,
+        quantizer: Optional[_QuantizerConfigCreate] = None,
         source_properties: Optional[List[str]] = None,
+        truncate: Optional[bool] = None,
         vector_index_config: Optional[_VectorIndexConfigCreate] = None,
         vectorize_collection_name: bool = True,
     ) -> _VectorConfigCreate:
@@ -1284,13 +1415,14 @@ class _Vectors:
 
         Args:
             name: The name of the vector.
-            quantizer: The quantizer to use for the vector index. If not provided, no quantization will be applied.
             base_url: The base URL to use where API requests should go. Defaults to `None`, which uses the server-defined default.
+            dimensions: The number of dimensions for the generated embeddings. Defaults to `None`, which uses the server-defined default.
             model: The model to use. Defaults to `None`, which uses the server-defined default.
                 See the
                 [documentation](https://weaviate.io/developers/weaviate/model-providers/voyageai/embeddings#available-models) for more details.
-            truncate: Whether to truncate the input texts to fit within the context length. Defaults to `None`, which uses the server-defined default.
+            quantizer: The quantizer to use for the vector index. If not provided, no quantization will be applied.
             source_properties: Which properties should be included when vectorizing. By default all text properties are included.
+            truncate: Whether to truncate the input texts to fit within the context length. Defaults to `None`, which uses the server-defined default.
             vector_index_config: The configuration for Weaviate's vector index. Use `wvc.config.Configure.VectorIndex` to create a vector index configuration. None by default
             vectorize_collection_name: Whether to vectorize the collection name. Defaults to `True`.
         """
@@ -1302,6 +1434,7 @@ class _Vectors:
                 vectorizeClassName=vectorize_collection_name,
                 baseURL=base_url,
                 truncate=truncate,
+                dimensions=dimensions,
             ),
             vector_index_config=_IndexWrappers.single(vector_index_config, quantizer),
         )
