@@ -9,6 +9,8 @@ from pydantic import AnyHttpUrl, AnyUrl, BaseModel, Field
 from weaviate.collections.classes.config import (
     AWSService,
     GenerativeSearches,
+    OpenAiReasoningEffort,
+    OpenAiVerbosity,
     _EnumLikeStr,
 )
 from weaviate.exceptions import WeaviateInvalidInputError
@@ -103,6 +105,7 @@ class _GenerativeAWS(_GenerativeConfigRuntime):
     generative: Union[GenerativeSearches, _EnumLikeStr] = Field(
         default=GenerativeSearches.AWS, frozen=True, exclude=True
     )
+    max_tokens: Optional[int]
     model: Optional[str]
     region: Optional[str]
     endpoint: Optional[AnyHttpUrl]
@@ -122,6 +125,7 @@ class _GenerativeAWS(_GenerativeConfigRuntime):
                 target_model=self.target_model,
                 target_variant=self.target_variant,
                 temperature=self.temperature,
+                # max_tokens=self.max_tokens,
                 images=_to_text_array(opts.images),
                 image_properties=_to_text_array(opts.image_properties),
             ),
@@ -317,6 +321,8 @@ class _GenerativeOpenAI(_GenerativeConfigRuntime):
     stop: Optional[List[str]]
     temperature: Optional[float]
     top_p: Optional[float]
+    verbosity: Optional[Union[OpenAiVerbosity, str]]
+    reasoning_effort: Optional[Union[OpenAiReasoningEffort, str]]
 
     def _to_grpc(self, opts: _GenerativeConfigRuntimeOptions) -> generative_pb2.GenerativeProvider:
         return generative_pb2.GenerativeProvider(
@@ -336,9 +342,37 @@ class _GenerativeOpenAI(_GenerativeConfigRuntime):
                 is_azure=self.is_azure,
                 images=_to_text_array(opts.images),
                 image_properties=_to_text_array(opts.image_properties),
+                verbosity=self.__verbosity(),
+                reasoning_effort=self.__reasoning_effort(),
             ),
         )
 
+    def __verbosity(self):
+        if self.verbosity is None:
+            return None
+
+        if self.verbosity == "low":
+            return generative_pb2.GenerativeOpenAI.Verbosity.VERBOSITY_LOW
+        if self.verbosity == "medium":
+            return generative_pb2.GenerativeOpenAI.Verbosity.VERBOSITY_MEDIUM
+        if self.verbosity == "high":
+            return generative_pb2.GenerativeOpenAI.Verbosity.VERBOSITY_HIGH
+        raise WeaviateInvalidInputError(f"Invalid verbosity value: {self.verbosity}")
+
+    def __reasoning_effort(self):
+        if self.reasoning_effort is None:
+            return None
+
+        if self.reasoning_effort == "minimal":
+            return generative_pb2.GenerativeOpenAI.ReasoningEffort.REASONING_EFFORT_MINIMAL
+        if self.reasoning_effort == "low":
+            return generative_pb2.GenerativeOpenAI.ReasoningEffort.REASONING_EFFORT_LOW
+        if self.reasoning_effort == "medium":
+            return generative_pb2.GenerativeOpenAI.ReasoningEffort.REASONING_EFFORT_MEDIUM
+        if self.reasoning_effort == "high":
+            return generative_pb2.GenerativeOpenAI.ReasoningEffort.REASONING_EFFORT_HIGH
+        raise WeaviateInvalidInputError(f"Invalid reasoning_effort value: {self.reasoning_effort}")
+
 
 class _GenerativeGoogle(_GenerativeConfigRuntime):
     generative: Union[GenerativeSearches, _EnumLikeStr] = Field(
@@ -411,6 +445,34 @@ class _GenerativeXAI(_GenerativeConfigRuntime):
         )
 
 
+class _GenerativeContextualAI(_GenerativeConfigRuntime):
+    generative: Union[GenerativeSearches, _EnumLikeStr] = Field(
+        default=GenerativeSearches.CONTEXTUALAI, frozen=True, exclude=True
+    )
+    model: Optional[str]
+    temperature: Optional[float]
+    top_p: Optional[float]
+    max_new_tokens: Optional[int]
+    system_prompt: Optional[str]
+    avoid_commentary: Optional[bool]
+    knowledge: Optional[List[str]]
+
+    def _to_grpc(self, opts: _GenerativeConfigRuntimeOptions) -> generative_pb2.GenerativeProvider:
+        self._validate_multi_modal(opts)
+        return generative_pb2.GenerativeProvider(
+            return_metadata=opts.return_metadata,
+            contextualai=generative_pb2.GenerativeContextualAI(
+                model=self.model,
+                temperature=self.temperature,
+                top_p=self.top_p,
+                max_new_tokens=self.max_new_tokens,
+                system_prompt=self.system_prompt,
+                avoid_commentary=self.avoid_commentary or False,
+                knowledge=_to_text_array(self.knowledge),
+            ),
+        )
+
+
 class GenerativeConfig:
     """Use this factory class to create the correct object for the `generative_provider` argument in the search methods of the `.generate` namespace.
 
@@ -474,6 +536,7 @@ class GenerativeConfig:
     def aws(
         *,
         endpoint: Optional[str] = None,
+        max_tokens: Optional[int] = None,
         model: Optional[str] = None,
         region: Optional[str] = None,
         service: Optional[Union[AWSService, str]] = None,
@@ -488,6 +551,7 @@ class GenerativeConfig:
 
         Args:
             endpoint: The endpoint to use when requesting the generation. Defaults to `None`, which uses the server-defined default
+            max_tokens: The maximum number of tokens to generate. Defaults to `None`, which uses the server-defined default
             model: The model to use. Defaults to `None`, which uses the server-defined default
             region: The AWS region to run the model from. Defaults to `None`, which uses the server-defined default
             service: The AWS service to use. Defaults to `None`, which uses the server-defined default
@@ -497,6 +561,7 @@ class GenerativeConfig:
         """
         return _GenerativeAWS(
             model=model,
+            max_tokens=max_tokens,
             region=region,
             service=service,
             endpoint=AnyUrl(endpoint) if endpoint is not None else None,
@@ -543,6 +608,38 @@ class GenerativeConfig:
             temperature=temperature,
         )
 
+    @staticmethod
+    def contextualai(
+        *,
+        model: Optional[str] = None,
+        max_new_tokens: Optional[int] = None,
+        temperature: Optional[float] = None,
+        top_p: Optional[float] = None,
+        system_prompt: Optional[str] = None,
+        avoid_commentary: Optional[bool] = None,
+        knowledge: Optional[List[str]] = None,
+    ) -> _GenerativeConfigRuntime:
+        """Create a `_GenerativeContextualAI` object for use with the `generative-contextualai` module.
+
+        Args:
+            model: The model to use. Defaults to `None`, which uses the server-defined default
+            max_new_tokens: The maximum number of tokens to generate. Defaults to `None`, which uses the server-defined default
+            temperature: The temperature to use. Defaults to `None`, which uses the server-defined default
+            top_p: The top P to use. Defaults to `None`, which uses the server-defined default
+            system_prompt: The system prompt to prepend to the conversation
+            avoid_commentary: Whether to avoid model commentary in responses
+            knowledge: Optional knowledge array to override the default knowledge from retrieved objects
+        """
+        return _GenerativeContextualAI(
+            model=model,
+            temperature=temperature,
+            top_p=top_p,
+            max_new_tokens=max_new_tokens,
+            system_prompt=system_prompt,
+            avoid_commentary=avoid_commentary,
+            knowledge=knowledge,
+        )
+
     @staticmethod
     def databricks(
         *,
@@ -758,10 +855,12 @@ class GenerativeConfig:
         max_tokens: Optional[int] = None,
         model: Optional[str] = None,
         presence_penalty: Optional[float] = None,
+        reasoning_effort: Optional[Union[OpenAiReasoningEffort, str]] = None,
         resource_name: Optional[str] = None,
         stop: Optional[List[str]] = None,
         temperature: Optional[float] = None,
         top_p: Optional[float] = None,
+        verbosity: Optional[Union[OpenAiVerbosity, str]] = None,
     ) -> _GenerativeConfigRuntime:
         """Create a `_GenerativeOpenAI` object for use when performing AI generation using the OpenAI-backed `generative-openai` module.
 
@@ -776,10 +875,12 @@ class GenerativeConfig:
             max_tokens: The maximum number of tokens to generate. Defaults to `None`, which uses the server-defined default
             model: The model to use. Defaults to `None`, which uses the server-defined default
             presence_penalty: The presence penalty to use. Defaults to `None`, which uses the server-defined default
+            reasoning_effort: The reasoning effort to use. Defaults to `None`, which uses the server-defined default
             resource_name: The name of the OpenAI resource to use. Defaults to `None`, which uses the server-defined default
             stop: The stop sequences to use. Defaults to `None`, which uses the server-defined default
             temperature: The temperature to use. Defaults to `None`, which uses the server-defined default
             top_p: The top P to use. Defaults to `None`, which uses the server-defined default
+            verbosity: The verbosity to use. Defaults to `None`, which uses the server-defined default
         """
         return _GenerativeOpenAI(
             api_version=api_version,
@@ -794,6 +895,8 @@ class GenerativeConfig:
             temperature=temperature,
             top_p=top_p,
             is_azure=False,
+            verbosity=verbosity,
+            reasoning_effort=reasoning_effort,
         )
 
     @staticmethod
@@ -842,6 +945,8 @@ class GenerativeConfig:
             temperature=temperature,
             top_p=top_p,
             is_azure=True,
+            verbosity=None,
+            reasoning_effort=None,
         )
 
     @staticmethod
