@@ -6,6 +6,7 @@ from typing import Optional, Tuple, Union, cast
 import httpx
 from grpc import Call, StatusCode  # type: ignore
 from grpc.aio import AioRpcError  # type: ignore
+from packaging import version
 
 ERROR_CODE_EXPLANATION = {
     413: """Payload Too Large. Try to decrease the batch size or increase the maximum request size on your weaviate
@@ -240,6 +241,22 @@ class WeaviateBatchError(WeaviateQueryError):
         self.message = message
 
 
+class WeaviateBatchSendError(WeaviateQueryError):
+    """Is raised if a gRPC batch send request to Weaviate fails in any way."""
+
+    def __init__(self, message: str):
+        super().__init__(message, "GRPC batch send")
+        self.message = message
+
+
+class WeaviateBatchStreamError(WeaviateQueryError):
+    """Is raised if a gRPC batch stream request to Weaviate fails in any way."""
+
+    def __init__(self, message: str):
+        super().__init__(message, "GRPC batch stream")
+        self.message = message
+
+
 class WeaviateDeleteManyError(WeaviateQueryError):
     """Is raised if a gRPC delete many request to Weaviate fails in any way."""
 
@@ -375,3 +392,14 @@ class WeaviateAgentsNotInstalledError(WeaviateBaseError):
         super().__init__(
             'Weaviate Agents (Alpha) functionality requires additional dependencies. Please install them using: "pip install weaviate-client[agents]"'
         )
+
+
+class WeaviateProtobufIncompatibility(Exception):
+    def __init__(self, pb: version.Version, grpc: version.Version) -> None:
+        super().__init__(
+            f"gRPC incompatibility detected. Protobuf: {pb.base_version}, gRPC: {grpc.base_version}. Ensure that your protobuf and grpcio versions are compatible or runtime errors may occur."
+        )
+
+
+class _BatchStreamShutdownError(Exception):
+    """Internal exception to signal that the batch stream was shutdown."""
