@@ -9,6 +9,7 @@ import re
 import uuid as uuid_lib
 from pathlib import Path
 from typing import Any, Dict, Generator, List, Optional, Sequence, Tuple, Union, cast
+from urllib.parse import quote
 
 import httpx
 import validators
@@ -407,6 +408,8 @@ def _capitalize_first_letter(string: str) -> str:
     Returns:
         The capitalized string.
     """
+    if len(string) == 0:
+        return ""
     if len(string) == 1:
         return string.capitalize()
     return string[0].capitalize() + string[1:]
@@ -739,3 +742,7 @@ class _WeaviateUUIDInt(uuid_lib.UUID):
     def __init__(self, hex_: int) -> None:
         object.__setattr__(self, "int", hex_)
         object.__setattr__(self, "is_safe", uuid_lib.SafeUUID.unknown)
+
+
+def escape_string(value: str) -> str:
+    return quote(value, safe="")
